'use strict';

/* eslint-env jest */
jest.mock('bleno/lib/characteristic');
jest.mock('../util/logger');
jest.mock('../packets/parse-packet');
jest.mock('../util/print-buffer');

var onWriteRequest = require('./on-write-request').default;
var mockLog = void 0;
var mockParsePacket = void 0;

beforeEach(function () {
  jest.resetAllMocks();
  mockLog = require('../util/logger').default;
  mockParsePacket = require('../packets/parse-packet').default;
});

test('should onWriteRequest(validData, 0, true, callback)', function () {
  var data = new Buffer([1, 2, 3, 4, 5]);
  var offset = 0;
  var withoutResponse = true;
  var callback = jest.fn();
  onWriteRequest(data, offset, withoutResponse, callback);
  expect(mockLog.mock).toMatchSnapshot();
  expect(mockLog.mock.calls.length).toEqual(2);
  expect(mockLog.mock.calls[0].length).toEqual(2);
  expect(callback.mock).toMatchSnapshot();
  expect(callback.mock.calls.length).toEqual(0);
  expect(mockParsePacket.mock).toMatchSnapshot();
});

test('should RESULT_UNLIKELY_ERROR onWriteRequest withoutResponse', function () {
  var data = new Buffer([1, 2, 3, 4, 5]);
  var callback = jest.fn();
  onWriteRequest(data, 0, false, callback);
  expect(mockLog.mock).toMatchSnapshot();
  expect(callback.mock).toMatchSnapshot();
  expect(callback.mock.calls.length).toEqual(1);
});

test('should RESULT_UNLIKELY_ERROR onWriteRequest with invalid offset', function () {
  var data = new Buffer([1, 2, 3, 4, 5]);
  var callback = jest.fn();
  onWriteRequest(data, 5, true, callback);
  expect(mockLog.mock).toMatchSnapshot();
  expect(callback.mock).toMatchSnapshot();
  expect(callback.mock.calls.length).toEqual(1);
});

test('should RESULT_UNLIKELY_ERROR onWriteRequest with invalid data', function () {
  var invalidData = new Buffer(0);
  var callback = jest.fn();
  onWriteRequest(invalidData, 0, true, callback);
  expect(mockLog.mock).toMatchSnapshot();
  expect(callback.mock).toMatchSnapshot();
  expect(callback.mock.calls.length).toEqual(1);
});