'use strict';

/* eslint-env jest */
jest.mock('../util/logger');
jest.mock('midi', function () {
  var midi = jest.fn();
  midi.getPortCount = function () {
    return 2;
  };
  midi.getPortName = function (portNum) {
    return 'MOCK_DEVICE_' + portNum;
  };
  midi.openVirtualPort = function () {};
  midi.closePort = function () {};
  midi.__mockBleno__ = true;
  return {
    input: function input() {
      return midi;
    },
    output: function output() {
      return midi;
    }
  };
});

var mockLog = void 0;
var mockMidi = void 0;
var listDevices = void 0;

beforeEach(function () {
  jest.resetAllMocks();
  mockLog = require('../util/logger').default;
  mockMidi = require('midi');
  listDevices = require('./list-devices').default;
});

[undefined, [], ['invalid'], ['input'], ['output'], ['output', 'input'], ['input', 'output'], ['input', 'invalid', 'output']].forEach(function (types) {
  test('listDevices(' + JSON.stringify(types) + ')', function () {
    listDevices(types);
    expect(mockLog.mock).toMatchSnapshot();
    expect(mockMidi.mock).toMatchSnapshot();
  });
});